function scopeHandles = RLSFilterSystemIDExampleApp(genCode,plotResults,numTSteps)
if nargin < 3
    numTSteps = Inf; % Run until user stops simulation. 
end
if nargin < 2
    plotResults = true; % Plot results
end
if nargin == 0
    genCode = false;  
end

% Create scopes only if plotResults is true
if plotResults

      
    scopes = load('RLSFiltersystemIdentificationScopes.mat');       
    tfescope   = scopes.tfescope;
    msescope   = scopes.msescope;
    screen = get(0,'ScreenSize');
    outerSize = min((screen(4)-40)/2, 512);
    tfescope.Position = [8, screen(4)-outerSize+8, outerSize+8,...
                            outerSize-92];
    msescope.Position = [8, screen(4)-2*outerSize+8, outerSize+8, ...
                            outerSize-92];
                                       
    %  forgetting factor
    Fs = 1e4;
    param = struct([]);
    param(1).Name = 'Cutoff Frequency (MH)';
    param(1).InitialValue = 0.48 * Fs/2;
    param(1).Limits = Fs/2 * [1e-5, .9999];
    param(2).Name = 'RLS  Factor';
    param(2).InitialValue = 0.99;
    param(2).Limits = [.3, 1];
    tuningUI = HelperCreateParamTuningUI(param, 'RLS FIR ','isInLegacyMode',false);
    set(tuningUI,'Position',[outerSize+32, screen(4)-2*outerSize+8, ...
        outerSize+8, outerSize-92]); 
else
    tfescope = [];
    msescope = [];
end

% Execute algorithm
while(numTSteps>=0)
    
    S = HelperUnpackUIData(tuningUI);
    
    if S.Pause
        drawnow limitrate;
        continue;
    end
    
    if S.Stop     
        break;
    end
    
    drawnow limitrate;  
    
    if ~genCode
        [tfe,err] = HelperRLSFilterSystemIdentificationSim(S);
    else
        [tfe,err] = HelperRLSFilterSystemIdentificationSimMEX(S);
    end

    if plotResults
            % Plot transfer functions
            tfescope(20*log10(abs(tfe)));
            % Plot learning curve
            msescope(10*log10(sum(err.^2)));
    end
    numTSteps = numTSteps - 1;
end

if ishghandle(tuningUI)  
    delete(tuningUI);
    drawnow;
    clear tuningUI
end
  
scopeHandles.tfescope = tfescope;
scopeHandles.msescope = msescope;


% Initialize the LMS filter with a length of 11 and step size of 0.05.
FrameSize = 100; NIter = 10;
lmsfilt2 = dsp.LMSFilter('Length',11,'Method','Normalized LMS', ...
    'StepSize',0.05);
firfilt2 = dsp.FIRFilter('Numerator', fir1(10,[.5, .75]));
sinewave = dsp.SineWave('Frequency',0.01, ...
    'SampleRate',1,'SamplesPerFrame',FrameSize);
TS = dsp.TimeScope('TimeSpan',FrameSize*NIter,'TimeUnits','Seconds',...
    'YLimits',[-3 3],'BufferLength',2*FrameSize*NIter, ...
    'ShowLegend',true,'ChannelNames', ...
    {'Noisy signal', 'Filtered signal'});
%%
% Pass the noisy input signal into the LMS filter and view the filtered 
% output in the time scope.
for k = 1:NIter
    x = randn(FrameSize,1);       % Input signal
    d = firfilt2(x) + sinewave(); % Noise + Signal
    [y,e,w] = lmsfilt2(x,d);
    TS([d,e]);          % Noisy = channel 1; Filtered = channel 2
end



